Learn R Programming

srvyr (version 0.1.1)

survey_quantile: Calculate the quantile and its variation using survey methods

Description

Calculate quantiles from complex survey data. A wrapper around svyquantile. survey_quantile and survey_median should always be called from summarise.

Usage

survey_quantile(x, quantiles, na.rm = FALSE, vartype = c("none", "se",
  "ci"), level = 0.95, q_method = "linear", f = 1,
  interval_type = c("Wald", "score", "betaWald"), ties = c("discrete",
  "rounded"), ...)

survey_median(x, na.rm = FALSE, vartype = c("none", "se", "ci"), level = 0.95, q_method = "linear", f = 1, interval_type = c("Wald", "score", "betaWald"), ties = c("discrete", "rounded"), ...)

Arguments

x
A variable or expression
quantiles
A vector of quantiles to calculate
na.rm
A logical value to indicate whether missing values should be dropped
vartype
Report variability as one or more of: standard error ("se", default), confidence interval ("ci") (variance and coefficient of variation not available).
level
A single number indicating the confidence level (only one level allowed)
q_method
See "method" in approxfun
interval_type
ties
...
Ignored

Examples

Run this code
library(survey)
data(api)

dstrata <- apistrat %>%
  as_survey_design(strata = stype, weights = pw)

dstrata %>%
  summarise(api99 = survey_quantile(api99, c(0.25, 0.5, 0.75)),
            api00 = survey_median(api00, vartype = c("ci")))

dstrata %>%
  group_by(awards) %>%
  summarise(api00 = survey_median(api00))

Run the code above in your browser using DataLab