Learn R Programming

srvyr (version 0.1.1)

survey_ratio: Calculate the ratio and its variation using survey methods

Description

Calculate ratios from complex survey data. A wrapper around svyratio. survey_ratio should always be called from summarise.

Usage

survey_ratio(numerator, denominator, na.rm = FALSE, vartype = c("se", "ci",
  "var", "cv"), level = 0.95, ...)

Arguments

numerator
The numerator of the ratio
denominator
The denominator of the ratio
na.rm
A logical value to indicate whether missing values should be dropped
vartype
Report variability as one or more of: standard error ("se", default), confidence interval ("ci"), variance ("var") or coefficient of variation ("cv").
level
A single number or vector of numbers indicating the confidence level
...
Ignored

Examples

Run this code
library(survey)
data(api)

dstrata <- apistrat %>%
  as_survey_design(strata = stype, weights = pw)

dstrata %>%
  summarise(enroll = survey_ratio(api00, api99, vartype = c("ci", "cv")))

dstrata %>%
  group_by(awards) %>%
  summarise(api00 = survey_ratio(api00, api99))

# level takes a vector for multiple levels of confidence intervals
dstrata %>%
  summarise(enroll = survey_ratio(api99, api00, vartype = "ci", level = c(0.95, 0.65)))

Run the code above in your browser using DataLab